"use strict";
const _path = /*#__PURE__*/ _interop_require_wildcard(require("path"));
const _javascriptobfuscator = require("javascript-obfuscator");
const _multistagesourcemap = require("multi-stage-sourcemap");
const _type = require("./type");
function _getRequireWildcardCache(nodeInterop) {
    if (typeof WeakMap !== "function") return null;
    var cacheBabelInterop = new WeakMap();
    var cacheNodeInterop = new WeakMap();
    return (_getRequireWildcardCache = function(nodeInterop) {
        return nodeInterop ? cacheNodeInterop : cacheBabelInterop;
    })(nodeInterop);
}
function _interop_require_wildcard(obj, nodeInterop) {
    if (!nodeInterop && obj && obj.__esModule) {
        return obj;
    }
    if (obj === null || typeof obj !== "object" && typeof obj !== "function") {
        return {
            default: obj
        };
    }
    var cache = _getRequireWildcardCache(nodeInterop);
    if (cache && cache.has(obj)) {
        return cache.get(obj);
    }
    var newObj = {
        __proto__: null
    };
    var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor;
    for(var key in obj){
        if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) {
            var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null;
            if (desc && (desc.get || desc.set)) {
                Object.defineProperty(newObj, key, desc);
            } else {
                newObj[key] = obj[key];
            }
        }
    }
    newObj.default = obj;
    if (cache) {
        cache.set(obj, newObj);
    }
    return newObj;
}
function loader(source, map) {
    const moduleRelativePath = _path.relative(this.rootContext, this.resourcePath);
    const options = this.getOptions();
    const logger = options[_type.LoggerSymbol];
    const publicEnvVariables = options[_type.PublicEnvVariablesSymbol];
    const sourceMapRequired = options.sourceMap;
    for (const [key, value] of publicEnvVariables.entries()){
        source = source.replaceAll(key, value);
    }
    const finalOptions = Object.assign(options, {
        ignoreRequireImports: true,
        inputFileName: moduleRelativePath,
        sourceMapMode: "separate"
    });
    // obfuscation
    const obfuscationResult = (0, _javascriptobfuscator.obfuscate)(source, finalOptions);
    const obfuscated = obfuscationResult.getObfuscatedCode();
    logger("Obfuscated:", moduleRelativePath, source.length, "->", obfuscated.length);
    // eslint-disable-next-line @typescript-eslint/init-declarations
    let sourceMap;
    if (map && sourceMapRequired) {
        sourceMap = (0, _multistagesourcemap.transfer)({
            fromSourceMap: obfuscationResult.getSourceMap(),
            toSourceMap: map
        });
    }
    this.callback(null, obfuscated, sourceMap);
}
module.exports = loader;
